Mixed-Up Code Questions
-----------------------

.. selectquestion:: list_MUC_Password_creator_sq
   :fromid: list_MUC_password_creator, list_MUC_password_creator_ac
   :toggle:

.. selectquestion:: list_MUC_rainfall_v2_sq
   :fromid: list_MUC_rainfall_v2, list_MUC_rainfall_v2_ac
   :toggle:

.. selectquestion:: list_MUC_mix_items_sq
   :fromid: list_MUC_mix_items, list_MUC_mix_items_ac
   :toggle:

.. selectquestion:: list_MUC_discount_sq
   :fromid: list_MUC_discount, list_MUC_discount_ac
   :toggle:

.. selectquestion:: list_MUC_append_if_a_sq
   :fromid: list_MUC_append_if_a, list_MUC_append_if_a_ac
   :toggle:

.. selectquestion:: list_MUC_add_vocab_sq
   :fromid: list_MUC_add_vocab, list_MUC_add_vocab_ac
   :toggle:
